@@ -19,9 +19,8 @@ def download_blob(bucket_name, source_file, destination_file):
     storage_client = storage.Client()
     bucket = storage_client.get_bucket(bucket_name)
     blob = bucket.blob(source_file)
-    blob.download_to_filename(destination_file)
-
-    print('File {} downloaded to {}.'.format(source_file, destination_file))
+    result = blob.download_as_string(destination_file)
+    return result
 
 
 class _BatchingFn(DoFn):
@@ -68,7 +67,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Multi Label Binarizer Variables
         # Split out Equipment Types
 
-        equipment_mlb = pickle.load(download_blob("user_transforms", "load_equipment_mlb.pkl", "load_equipment_mlb.pkl"))
+        equipment_mlb = pickle.load(download_blob("user_transforms", "user_equipment_mlb.pkl", "user_equipment_mlb.pkl"))
         state_lbe = pickle.load(download_blob("user_transforms", "user_state_lbe.pkl", "user_state_lbe.pkl"))
         state_ohe = pickle.load(download_blob("user_transforms", "user_state_ohe.pkl", "user_state_ohe.pkl"))
         city_lbe = pickle.load(download_blob("user_transforms", "user_city_lbe.pkl", "user_city_lbe.pkl"))
